@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE RecordWildCards #-}
@@ -62,13 +63,19 @@ makeRequest' :: HT.Method -- ^ HTTP request method (GET or POST)
              -> HT.SimpleQuery -- ^ Query
              -> IO HTTP.Request
 makeRequest' m url query = do
+#if MIN_VERSION_http_client(0,4,30)
+    req <- HTTP.parseRequest url
+#else
     req <- HTTP.parseUrl url
+#endif
     let addParams =
             if m == "POST"
             then HTTP.urlEncodedBody query
             else \r -> r { HTTP.queryString = HT.renderSimpleQuery False query }
     return $ addParams $ req { HTTP.method = m
+#if !MIN_VERSION_http_client(0,4,30)
                              , HTTP.checkStatus = \_ _ _ -> Nothing
+#endif
                              }
 
 getResponse :: MonadResource m
@@ -263,7 +270,6 @@ sourceWithCursor info mgr req = loop (-1)
 --
 -- This function cooperate with instances of 'HasCursorParam'.
 sourceWithCursor' :: ( MonadBase IO m
-                     , FromJSON responseType
                      , CursorKey ck
                      , HasCursorParam (APIRequest apiName (WithCursor ck responseType))
                      )
@@ -273,9 +279,8 @@ sourceWithCursor' :: ( MonadBase IO m
                   -> C.Source m Value
 sourceWithCursor' info mgr req = loop (-1)
   where
-    relax :: FromJSON value
-          => APIRequest apiName (WithCursor ck responseType)
-          -> APIRequest apiName (WithCursor ck value)
+    relax :: APIRequest apiName (WithCursor ck responseType)
+          -> APIRequest apiName (WithCursor ck Value)
     relax = unsafeCoerce
     loop 0 = CL.sourceNull
     loop cur = do
@@ -286,7 +291,6 @@ sourceWithCursor' info mgr req = loop (-1)
 -- | A wrapper function to perform multiple API request with @SearchResult@.
 sourceWithSearchResult :: ( MonadBase IO m
                           , FromJSON responseType
-                          , HasMaxIdParam (APIRequest apiName (SearchResult [responseType]))
                           )
                        => TWInfo -- ^ Twitter Setting
                        -> HTTP.Manager
@@ -309,7 +313,6 @@ sourceWithSearchResult info mgr req = do
 
 -- | A wrapper function to perform multiple API request with @SearchResult@.
 sourceWithSearchResult' :: ( MonadBase IO m
-                           , HasMaxIdParam (APIRequest apiName (SearchResult [responseType]))
                            )
                         => TWInfo -- ^ Twitter Setting
                         -> HTTP.Manager
@@ -322,9 +325,8 @@ sourceWithSearchResult' info mgr req = do
     return $ res & searchResultStatuses .~ body
   where
     origQueryMap = req ^. params . to M.fromList
-    relax :: FromJSON value
-          => APIRequest apiName (SearchResult responseType)
-          -> APIRequest apiName (SearchResult value)
+    relax :: APIRequest apiName (SearchResult [responseType])
+          -> APIRequest apiName (SearchResult [Value])
     relax = unsafeCoerce
     loop Nothing = CL.sourceNull
     loop (Just nextResultsStr) = do
